@@ -82,7 +82,7 @@ my $max_mpi_ranks_filename = "max-mpi-ranks";
 
 # List of all the generic subdirectories of tests; pdb2gmx and essentialdynamics are treated
 # separately.
-my @all_dirs = ('complex', 'freeenergy', 'extra');
+my @all_dirs = ('complex', 'extra');
 
 # Return the command-line option specifying the number of separate
 # PME ranks to use, if appropriate (ie the .mdp file specifies a
@@ -873,12 +873,6 @@ sub test_case {
             if (! -f $reflog ) {
                 copy($log, $reflog);
             }
-
-            # This bit below is only relevant for free energy tests
-            my $refxvg = "$input_dir/${ref}.xvg";
-            my $nerr_xvg = check_xvg($refxvg,'dgdl.xvg',1);
-            push(@error_detail, "$refxvg ($nerr_xvg errors)") if ($nerr_xvg > 0);
-            $nerror |= $nerr_xvg;
         }
         else {
             print "mdrun output files ${ener} and/or ${traj} were not found.\n";
@@ -998,7 +992,7 @@ sub test_systems {
         # kernels. If GPU kernels were used to run this test case
         # (whether natively or in emulation), run it again in CPU-only
         # mode. This relies on test_case() not clearing up md.log.
-        my $mdrun_ran_nb_on_gpu = (find_in_file("^Using .* 8x8 nonbonded short-range kernels", "$dir/md.log") > 0);
+        my $mdrun_ran_nb_on_gpu = (find_in_file("^Using GPU .x. nonbonded short-range kernels", "$dir/md.log") > 0);
         my $specified_nb_option = ($mdparams =~ /-nb/);
         if ($mdrun_ran_nb_on_gpu) {
             if ($specified_nb_option) {
